/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kdialog.ProgressDialog.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef PROGRESSDIALOGADAPTOR_H
#define PROGRESSDIALOGADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "progressdialog.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kdialog.ProgressDialog
 */
class ProgressDialogAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kdialog.ProgressDialog")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kdialog.ProgressDialog\">\n"
"    <property access=\"readwrite\" type=\"i\" name=\"maximum\"/>\n"
"    <property access=\"readwrite\" type=\"i\" name=\"value\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"autoClose\"/>\n"
"    <method name=\"setLabelText\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"label\"/>\n"
"    </method>\n"
"    <method name=\"showCancelButton\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"value\"/>\n"
"    </method>\n"
"    <method name=\"wasCancelled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"close\"/>\n"
"  </interface>\n"
        "")
public:
    ProgressDialogAdaptor(ProgressDialog *parent);
    ~ProgressDialogAdaptor() override;

    inline ProgressDialog *parent() const
    { return static_cast<ProgressDialog *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(bool autoClose READ autoClose WRITE setAutoClose)
    bool autoClose() const;
    void setAutoClose(bool value);

    Q_PROPERTY(int maximum READ maximum WRITE setMaximum)
    int maximum() const;
    void setMaximum(int value);

    Q_PROPERTY(int value READ value WRITE setValue)
    int value() const;
    void setValue(int value);

public Q_SLOTS: // METHODS
    void close();
    void setLabelText(const QString &label);
    void showCancelButton(bool value);
    bool wasCancelled();
Q_SIGNALS: // SIGNALS
};

#endif
