/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kdialog.ProgressDialog.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "progressdialogadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ProgressDialogAdaptor
 */

ProgressDialogAdaptor::ProgressDialogAdaptor(ProgressDialog *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ProgressDialogAdaptor::~ProgressDialogAdaptor()
{
    // destructor
}

bool ProgressDialogAdaptor::autoClose() const
{
    // get the value of property autoClose
    return qvariant_cast< bool >(parent()->property("autoClose"));
}

void ProgressDialogAdaptor::setAutoClose(bool value)
{
    // set the value of property autoClose
    parent()->setProperty("autoClose", QVariant::fromValue(value));
}

int ProgressDialogAdaptor::maximum() const
{
    // get the value of property maximum
    return qvariant_cast< int >(parent()->property("maximum"));
}

void ProgressDialogAdaptor::setMaximum(int value)
{
    // set the value of property maximum
    parent()->setProperty("maximum", QVariant::fromValue(value));
}

int ProgressDialogAdaptor::value() const
{
    // get the value of property value
    return qvariant_cast< int >(parent()->property("value"));
}

void ProgressDialogAdaptor::setValue(int value)
{
    // set the value of property value
    parent()->setProperty("value", QVariant::fromValue(value));
}

void ProgressDialogAdaptor::close()
{
    // handle method call org.kde.kdialog.ProgressDialog.close
    parent()->close();
}

void ProgressDialogAdaptor::setLabelText(const QString &label)
{
    // handle method call org.kde.kdialog.ProgressDialog.setLabelText
    parent()->setLabelText(label);
}

void ProgressDialogAdaptor::showCancelButton(bool value)
{
    // handle method call org.kde.kdialog.ProgressDialog.showCancelButton
    parent()->showCancelButton(value);
}

bool ProgressDialogAdaptor::wasCancelled()
{
    // handle method call org.kde.kdialog.ProgressDialog.wasCancelled
    return parent()->wasCancelled();
}


#include "moc_progressdialogadaptor.cpp"
